API
===

This is the internal API reference for ibek


.. automodule ibek

``ibek``
~~~~~~~~

.. data:: ibek.__version__
    :type: str

    Version number as calculated by https://github.com/pypa/setuptools_scm

``ibek.globals``
----------------

.. automodule:: ibek.globals
    :members:

``ibek.support``
----------------

.. automodule:: ibek.support
    :members:

``ibek.ioc``
------------------

.. automodule:: ibek.ioc
    :members:


``ibek.render``
---------------

.. automodule:: ibek.render
    :members:

``ibek.utils``
---------------

.. automodule:: ibek.utils
    :members:

.. class:: apischema.types.UndefinedType

    A sentinel value that allows detection that a value has not been passed at init
